==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/RELIABILITYRANKINGSURVEYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour RELIABILITYRANKINGSURVEYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RELIABILITYRANKINGSURVEYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGLEVELPK"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SURVEYTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RELIABILITYRANKINGSURVEYID_Type", propOrder = {
    "equipmentid",
    "reliabilityrankinglevelpk",
    "surveytype"
})
public class RELIABILITYRANKINGSURVEYID_Type {

    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "RELIABILITYRANKINGLEVELPK", required = true)
    protected String reliabilityrankinglevelpk;
    @XmlElement(name = "SURVEYTYPE", required = true)
    protected String surveytype;

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété reliabilityrankinglevelpk.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGLEVELPK() {
        return reliabilityrankinglevelpk;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankinglevelpk.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGLEVELPK(String value) {
        this.reliabilityrankinglevelpk = value;
    }

    /**
     * Obtient la valeur de la propriété surveytype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSURVEYTYPE() {
        return surveytype;
    }

    /**
     * Définit la valeur de la propriété surveytype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSURVEYTYPE(String value) {
        this.surveytype = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/RELIABILITYRANKINGSURVEYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RELIABILITYRANKINGSURVEYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RELIABILITYRANKINGSURVEYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGLEVELPK"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SURVEYTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RELIABILITYRANKINGSURVEYID_Type", propOrder = {
    "equipmentid",
    "reliabilityrankinglevelpk",
    "surveytype"
})
public class RELIABILITYRANKINGSURVEYID_Type {

    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "RELIABILITYRANKINGLEVELPK", required = true)
    protected String reliabilityrankinglevelpk;
    @XmlElement(name = "SURVEYTYPE", required = true)
    protected String surveytype;

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the reliabilityrankinglevelpk property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGLEVELPK() {
        return reliabilityrankinglevelpk;
    }

    /**
     * Sets the value of the reliabilityrankinglevelpk property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGLEVELPK(String value) {
        this.reliabilityrankinglevelpk = value;
    }

    /**
     * Gets the value of the surveytype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSURVEYTYPE() {
        return surveytype;
    }

    /**
     * Sets the value of the surveytype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSURVEYTYPE(String value) {
        this.surveytype = value;
    }

}
